# Code of Conduct

## Our Pledge

We pledge to make participation in this project a harassment-free experience for everyone.

## Standards

- Be respectful and professional.
- Assume good intent.
- Give actionable technical feedback.
- Avoid personal attacks.

## Enforcement

Project maintainers may remove comments, issues, commits, or contributors that violate this code of conduct.

## Reporting

Report concerns privately to the maintainers via GitHub issue contact details.
